import type { ExecutionContext } from "ava";
import { Libp2p } from "libp2p";
import { Awaitable, Message, Signature } from "@canvas-js/interfaces";
import { ServiceMap, AbstractGossipLog } from "@canvas-js/gossiplog";
import { GossipLogServiceInit } from "@canvas-js/gossiplog/service";
export type NetworkInit = Record<string, {
    port: number;
    peers?: string[];
}>;
export declare function createNetwork<T extends NetworkInit, Payload>(t: ExecutionContext<unknown>, openMessageLog: () => Awaitable<AbstractGossipLog<Payload>>, networkInit: T, serviceInit?: GossipLogServiceInit, options?: {
    start?: boolean;
    minConnections?: number;
    maxConnections?: number;
}): Promise<{
    [K in keyof T]: Libp2p<ServiceMap<Payload>>;
}>;
/**
 * waits for every peer to open `minConnections` distinct connections
 */
export declare function waitForInitialConnections<Payload>(network: Record<string, Libp2p<ServiceMap<Payload>>>, options?: {
    minConnections?: number;
}): Promise<void>;
export declare function waitForGraft<Payload>(network: Record<string, Libp2p<ServiceMap<Payload>>>, links: [string, string][]): Promise<void>;
/**
 * waits for every peer to emit a `sync` event for every other peer
 */
export declare function waitForInitialSync<Payload>(network: Record<string, Libp2p<ServiceMap<Payload>>>, links: [string, string][]): Promise<void>;
type Result = {
    id: string;
    signature: Signature;
    message: Message;
};
export declare function waitForMessageDelivery<Payload>(t: ExecutionContext<unknown>, network: Record<string, Libp2p<ServiceMap<Payload>>>, match: (id: string, signature: Signature, message: Message) => boolean): Promise<Result>;
export {};
